﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Linq;

namespace Validacao_SilverLight
{
    public class Contato : INotifyPropertyChanged
    {
        // implementação da interface INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(PropertyChangedEventArgs e)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, e);
        }

        public Contato()
        {
        }

        private string _Nome;
        public string Nome
        {
            get { return _Nome; }
            set
            {
                string ValorAnterior = _Nome;
                if (ValorAnterior != value)
                {
                    _Nome = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Nome"));
                }
            }
        }//_Nome

        private string _Email;
        public string Email
        {
            get { return _Email; }
            set
            {
                string ValorAnterior = _Email;
                if (ValorAnterior != value)
                {
                    _Email = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Email"));
                }
            }
        }//_Email

        private string _Telefone;
        public string Telefone
        {
            get { return _Telefone; }
            set
            {
                string ValorAnterior = _Telefone;

                if (value.Length != 10)
                    throw new Exception("O númreo do telefone deve ter 10 dígitos");
                try
                {
                    Convert.ToInt64(value);
                }
                catch
                {
                    throw new Exception("O númreo do telefone deve ter 10 dígitos");
                }

                if (ValorAnterior != value)
                {
                    _Telefone = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Telefone"));
                }
            }
        }//_Telefone

        private Endereco _Endereco;
        public Endereco Endereco
        {
            get { return _Endereco; }
            set
            {
                Endereco ValorAnterior = _Endereco;
                if (ValorAnterior != value)
                {
                    _Endereco = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Endereco"));
                }
            }
        }//_Endereco

        private bool _InError = default(bool);
        public bool InError
        {
            get
            {
                return _InError;
            }

            set
            {
                if (value != _InError)
                {
                    _InError = value;
                    if (PropertyChanged != null)
                        PropertyChanged(this, new PropertyChangedEventArgs("InError"));
                }

            }
        }
    }//Contato

    public class Endereco : INotifyPropertyChanged
    {
        private static List<string> EstadoLista =
          new List<string>(){ "AC","AL","AP","AM","BA","CE","DF","ES","GO","MA","MT",
        "MS","MG","PA","PB","PR","PE","PI","RJ","RN","RS","RO","RR","SC","SP","SE",
        "TO"};

        public event PropertyChangedEventHandler PropertyChanged;
        private void RaisePropertyChanged(PropertyChangedEventArgs e)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, e);
        }

        private string _Rua;
        public string Rua
        {
            get { return _Rua; }
            set
            {
                string ValorAnterior = _Rua;
                if (ValorAnterior != value)
                {
                    _Rua = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Rua"));
                }
            }
        }//_Rua

        private string _Cidade;
        public string Cidade
        {
            get { return _Cidade; }
            set
            {
                string ValorAnterior = _Cidade;

                if (ValorAnterior != value)
                {
                    _Cidade = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Cidade"));
                }
            }
        }//_Cidade

        private string _Estado;
        public string Estado
        {
            get { return _Estado; }
            set
            {
                string ValorAnterior = _Estado;
                //estado deve ter 2 caracteres
                if (EstadoLista.Contains(value) == false)
                    throw new Exception(
                      "A sigla do estado deve possuir duas Letras"
                      );

                if (ValorAnterior != value)
                {
                    _Estado = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Estado"));
                }
            }
        }//_Estado

        private string _Cep;
        public string Cep
        {
            get { return _Cep; }
            set
            {
                string ValorAnterior = _Cep;
                //cep deve ter 8 caracteres
                if (value.Length != 8)
                {
                    throw new Exception("O Cep deve conter 8 dígitos numéricos");
                }

                try
                {
                    Convert.ToInt32(value);
                }
                catch
                {
                    throw new Exception("O Cep deve conter 8 dígitos numéricos");
                }

                if (ValorAnterior != value)
                {
                    _Cep = value;
                    RaisePropertyChanged(new PropertyChangedEventArgs("Cep"));
                }
            }
        }//_Cep
    }//Endereco   
}

